@@ -1,7 +1,7 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -17,6 +17,7 @@ use Clone;
 use HTML::AutoTag;
 use Math::Matrix;
 
+use Spreadsheet::HTML::Engine;
 use Spreadsheet::HTML::Presets;
 use Spreadsheet::HTML::File::Loader;
 
@@ -302,6 +303,10 @@ sub _args {
         ];
     }
 
+    if ($args->{apply}) {
+        $data = Spreadsheet::HTML::Engine::apply( $data, $args->{apply} );
+    }
+
     $args->{_max_rows} = scalar @{ $data }      || 1;
     $args->{_max_cols} = scalar @{ $data->[0] } || 1;
 
@@ -347,6 +352,7 @@ Spreadsheet::HTML - Just another HTML table generator.
     $data = [ [qw(a1 a2 a3)], [qw(b1 b2 b3)], [qw(c1 c2 c3)] ];
 
     $generator = Spreadsheet::HTML->new( data => $data, indent => "\t" );
+
     print $generator->portrait;
     print $generator->landscape( encodes => '<>' );
 
@@ -363,11 +369,11 @@ Procedural interface:
 
 =head1 DESCRIPTION
 
-Generate HTML tables with ease (HTML4, XHTML and HTML5). Can generate
-landscape and other rotated views, Handsontable tables, HTML calendars,
-checkerboard patterns, games such as sudoku, banners and mazes, and can
-create animations of cell values and backgrounds via jQuery. Can rewrap
-existing tables from Excel, HTML, JSON, CSV and YAML files.
+Generate HTML tables with ease (HTML4, XHTML and HTML5). Generate
+portrait, landscape and other rotated views, Handsontable tables, HTML
+calendars, checkerboard patterns, games such as sudoku, banners and mazes,
+and create animations of cell values and backgrounds via supplied jQuery.
+Rewrap existing tables from Excel, HTML, JSON, CSV and YAML files.
 
 THIS MODULE IS AN ALPHA RELEASE! Although we are very close to BETA.
 
@@ -456,9 +462,9 @@ For most cases, C<portrait> and C<landscape> are all you need.
 =head1 PARAMETERS
 
 All methods/procedures accept the same named parameters. All
-parameters are initally undefined.  You do not have to specify
-C<data>, any bare array references will be collected and assigned
-to C<data>.
+parameters are initally undefined.  You do not necessarily have
+to specify C<data>, any bare array references will be collected
+and assigned to C<data>.
 
 =head2 LITERAL PARAMETERS
 
@@ -517,6 +523,19 @@ of likely mangling the headings.
 
   wrap => 10 
 
+=item * C<apply>
+
+Applies formulas parsable by Spreadsheet::Engine to data.
+
+  apply => 'set B6 formula SUM(B2:B5)'
+
+Accepts lists:
+
+  apply => ['set B6 formula SUM(B2:B5)', 'set C6 formula SUM(C2:C5)']
+
+Can be used to create total and sub total rows. See
+L<Spreadsheet::Engine> for more.
+
 =item * C<theta: 0, 90, 180, 270, -90, -180, -270>
 
 Rotates table clockwise for positive values and 
@@ -820,6 +839,14 @@ Useful for preventing data from being clobbered.
 
 =head1 OPTIONAL
 
+The following is used to apply formulas to data:
+
+=over 4
+
+=item * L<Spreadsheet::Engine>
+
+=back
+
 The following are used to load data from various
 different file formats:
 
