@@ -12,9 +12,12 @@ sub beadwork {
     ($self,$data,$args) = $self ? $self->_args( @_ ) : Spreadsheet::HTML::_args( @_ );
 
     my %presets = (
-        dk    => \&_dk,
-        mario => \&_mario,
-        '1up' => \&_1up,
+        dk          => \&_dk,
+        mario       => \&_mario,
+        '1up'       => \&_1up,
+        apple       => \&_apple,
+        cartman     => \&_cartman,
+        homer       => \&_homer,
     );
 
     if ($args->{preset}) {
@@ -42,7 +45,13 @@ sub beadwork {
         return $self ? $self->generate( %$args ) : Spreadsheet::HTML::generate( %$args );
     }
 
+    # override any mapped colors
     $args->{map}{'.'} = $args->{bgcolor} if defined $args->{bgcolor};
+    my %map_args = map {($_ => $args->{$_})} grep /^-\d+$/, keys %$args;
+    for (keys %map_args) {
+        (my $key) = $_ =~ /(\d+)/;
+        $args->{map}{$key} = $map_args{$_};
+    }
 
     my @lines = grep ! $_ =~ /^\s*$/, split /\n/, $args->{art};
     my $total_rows = scalar @lines;
@@ -71,7 +80,6 @@ sub beadwork {
         tgroups  => 0,
         headless => 0,
         matrix   => 1,
-        wrap     => 0,
         fill     => join( 'x', $total_rows, $total_cols ),
     );
 
@@ -133,22 +141,24 @@ sub _1up {
     my $args = shift;
 
     $args->{art} = '
-.....111111.....
-...1122223311...
-..133222233331..
-.13222222233331.
-.13223333222331.
-1222333333222221
-1222333333223321
-1322333333233331
-1332233332233331
-1332222222223321
-1322111111112221
-.11133133133111.
-..133313313331..
-..133333333331..
-...1333333331...
-....11111111....
+..................
+......111111......
+....1122223311....
+...133222233331...
+..13222222233331..
+..13223333222331..
+.1222333333222221.
+.1222333333223321.
+.1322333333233331.
+.1332233332233331.
+.1332222222223321.
+.1322111111112221.
+..11133133133111..
+...133313313331...
+...133333333331...
+....1333333331....
+....11111111......
+..................
 ';
 
     $args->{map} = {
@@ -165,22 +175,24 @@ sub _mario {
     my $args = shift;
 
     $args->{art} = '
-...111111....
-..1111111111.
-..22244434...
-.24244443444.
-.242244442444
-.22444442222.
-...44444444..
-..3313331....
-.33313331333.
-3333111113333
-4431111111344
-4441111111444
-4411111111144
-..111...111..
-.333.....333.
-2222.....2222
+...............
+....111111.....
+...1111111111..
+...22244434....
+..24244443444..
+..242244442444.
+..22444442222..
+....44444444...
+...3313331.....
+..33313331333..
+.3333111113333.
+.4431111111344.
+.4441111111444.
+.4411111111144.
+...111...111...
+..333.....333..
+.2222.....2222.
+...............
 ';
 
     $args->{map} = {
@@ -194,11 +206,164 @@ sub _mario {
     return $args;
 }
 
+sub _apple {
+    my $args = shift;
+
+    $args->{art} = '
+...............................
+...................11..........
+..................111..........
+.................111...........
+................111............
+................11.............
+................1..............
+.........111111...1111111......
+.......11111111111111111111....
+.....111111111111111111111111..
+....2222222222222222222222222..
+...2222222222222222222222222...
+..2222222222222222222222222....
+..2222222222222222222222222....
+..333333333333333333333333.....
+.3333333333333333333333333.....
+.3333333333333333333333333.....
+.3333333333333333333333333.....
+.4444444444444444444444444.....
+..4444444444444444444444444....
+..4444444444444444444444444....
+..444444444444444444444444444..
+..5555555555555555555555555555.
+...555555555555555555555555555.
+...555555555555555555555555555.
+....5555555555555555555555555..
+.....66666666666666666666666...
+......666666666...666666666....
+.......6666666.....6666666.....
+........66666.......66666......
+...............................
+';
+
+    $args->{map} = {
+        '.' => 'white',
+        1 => '#28921c', # green
+        2 => '#ffc620', # yellow
+        3 => '#ff7f27', # orange
+        4 => '#ff1c1c', # red
+        5 => '#ba2049', # purple
+        6 => '#1c51db', # blue
+    };
+
+    return $args;
+}
+
+sub _cartman {
+    my $args = shift;
+
+    $args->{art} = '
+.................................
+..............11111..............
+............112222211............
+..........1122322322311..........
+........11333333333333311........
+.......1333333333333333331.......
+......133333313333313333331......
+......133444441222144443331......
+.....13444411111411111444431.....
+.....14444155551415555144441.....
+....1444415555551555555144441....
+....1444415555151515555144441....
+....1444415555551555555144441....
+....1444441555514155551444441....
+....1444444111144411114444441....
+.....14444444444444444444441.....
+.....14444444444444444444441.....
+....1114444444444444444444111....
+...166614444444444444444416661...
+..16666614444444111444441666661..
+..11666661444441444444416666611..
+.1221661661144444444411661661221.
+.1222116666611111111166666112221.
+.1222216666666666666666666122221.
+.1221216666666666666666666121221.
+..11616666666666666666666661611..
+...166666666666666666666666661...
+...111111116666666666666666661...
+...177777771166661111111111111...
+...17777777771111777777777771....
+....1771111117777111111117771....
+....1111111111111111111111111....
+.................................
+';
+
+    $args->{map} = {
+        '.' => 'white',
+        1 => 'black', # black
+        2 => '#ffd800', # yellow
+        3 => '#0094ff', # blue
+        4 => '#ffbd77', # tan
+        5 => 'white', # white
+        6 => 'red', # red
+        7 => '#7f3300', # brown
+    };
+
+    return $args;
+}
+
+sub _homer {
+    my $args = shift;
+
+    $args->{art} = '
+........................
+....1111................
+...111..1...............
+..11..111111............
+.1.11122222211..........
+.1.122222222221.........
+..12122222222221........
+..12222222222221........
+.1222222222222221.......
+.122222222222222111.....
+.1222222222111113331....
+.12222222213333133331...
+.12222222133333313131...
+.12222222133333313331...
+..122122213331331111....
+..1221122213333122221...
+..1112212221111222221...
+..1.1122222222221111....
+....11122222211144441...
+....122222221444444441..
+....122122214444444441..
+.....112221444444444441.
+......12221414444444441.
+......1222141111111111..
+......1222144444441.....
+......122221444441......
+......122221444441......
+.....112222214441.......
+....13311222211111......
+....133331122222131.....
+...113333331122213311...
+..1331333333112213331...
+........................
+';
+
+    $args->{map} = {
+        '.' => 'white',
+        1 => 'black', # black
+        2 => '#ffd800', # yellow
+        3 => 'white', # white
+        4 => '#7f3300', # brown
+    };
+
+    return $args;
+}
+
 1;
 
 =head1 NAME
 
-Spreadsheet::HTML::Presets::Beadwork - create artful patterns.
+Spreadsheet::HTML::Presets::Beadwork - Generate patterns in HTML table cell backgrounds.
 
 =head1 DESCRIPTION
 
@@ -234,6 +399,10 @@ Generates beadwork patters in the name of ASCII art.
       bgcolor => 'gray',
   )
 
+C<art> contains the ASCII picture and C<map> contains the color
+for each symbol in the ASCII picture in a hash. See source code
+for preset examples of the art and map data structures.
+
 Some prefabricated examples are available via the C<preset> param:
 
 =over 4
@@ -244,10 +413,28 @@ Some prefabricated examples are available via the C<preset> param:
 
 =item * C<1up>
 
+=item * C<apple>
+
+=item * C<cartman>
+
+=item * C<homer>
+
 =back
 
   beadwork( preset => 'dk' )
 
+Mapped colors can be overriden by their key number:
+
+  beadwork( 
+      art => '/path/to/ascii-art.txt',
+      map => '/path/to/mappings.json',
+      -3  => 'blue',
+  )
+
+Works well with presets. Change Cartman's cap and mitten colors:
+
+  beadwork( preset => 'carman', -2 => 'purple', -3 => 'green' )
+
 =back
 
 =head1 SEE ALSO
